==> sems-0.8.12.tar.gz: sems-0.8.12/plug-in/isdngw/IsdnCapiConnection.h <==
#ifdef USE_CAPI20

#ifndef _ISDNCAPICONNECTION_H_
#define _ISDNCAPICONNECTION_H_

#include "AmApi.h"
#include <capi20.h>
#include "IsdnCapiUtil.h"
#include "IsdnCall.h"
#include "globals.h"

/* represents a CAPI 2.0 audio connection */

#define NUM_BUF_LEN 100
#define AUDIO_BUFFER_LEN (MSG_SIZE*2)
#define AUDIO_CHUNK_SIZE 160

#define REASON_LEN 1000

#define CC_TYPE_INBOUND 1
#define CC_TYPE_OUTBOUND 2

#define MAX_DATABUF 10

class IsdnCapiConnection {
	
	public:
	
	IsdnCapiConnection(); /* constructor */
	IsdnCapiConnection(int controller, int type = CC_TYPE_OUTBOUND);
	~IsdnCapiConnection();

	void setCall(IsdnCall*);
	IsdnCall* getCall();

	static IsdnCapiConnection* incomingCall(_cmsg *msg);
	
	int placeCall(AmRequest *req, char* callee_number, char* msn); /* place a call */
	int accept(); /* accept a call */
	int hangup(); /* hangup a call */

	void onBeforeCallAccept(AmRequest* req);
	bool isIncoming();
	void connectIncoming();

	/* callback functions: */
	int cb_connect_conf(_cmsg *msg);
	int cb_connect_active_ind(_cmsg* msg);
	int cb_connect_b3_active_ind(_cmsg* msg);
	int cb_connect_b3_conf(_cmsg* msg);
	int cb_connect_b3_ind(_cmsg* msg);
	int cb_connect_ind(_cmsg* msg);
	int cb_alert_conf(_cmsg* msg);
	int cb_data_b3_ind(_cmsg* msg);
	int cb_data_b3_conf(_cmsg* msg);
	int cb_disconnect_ind(_cmsg* msg);
	int cb_disconnect_conf(_cmsg* msg);
	int cb_disconnect_b3_ind(_cmsg* msg);

	/* these are used for actual voice transfer, format is aLaw */
	int getVoiceStream(unsigned char *buf, int size);  /* get audio bytes */
	int putVoiceStream(unsigned char *buf, int size);  /* put audio bytes */

	char m_from[MAX_NUM_LEN];
	char m_to[MAX_NUM_LEN];

	void lockAdr();
	void unlockAdr();
	unsigned int getAdr();
	void setAdr(unsigned);

	bool getAudioConnected();
	int getController();
	private:
	
	unsigned char audiotosend[MSG_SIZE][MAX_DATABUF];
	int cur_databuf;
	
	int call(char* caller_number, char* callee_number, int shownumber); /* place a call */

	IsdnCall* m_call;

	int id;
	int state;
	unsigned int adr;
	int m_controller;

	int type;

	int m_code;
	char m_reason[REASON_LEN];

	bool audioConnected;

	/* audio data FromIsdn */
	unsigned char fi_audiobuffer[AUDIO_BUFFER_LEN+1];
	unsigned char* fi_readpos;
	unsigned int fi_datalen;
	pthread_mutex_t fi_m;

	/* audio data ToIsdn */
	unsigned char ti_audiobuffer[AUDIO_BUFFER_LEN+1];
	unsigned char* ti_readpos;
	unsigned int ti_datalen;
	pthread_mutex_t ti_m;

	int readFromBuffer(unsigned char* audiobuffer, unsigned char** readpos, unsigned int *datalen, unsigned char* targetbuffer, int bytes);
	int  writeToBuffer(unsigned char* audiobuffer, unsigned char*  readpos, unsigned int *datalen, unsigned char* data, unsigned int bytes);
	
	/* connection setup lock: lock, trigger the call, lock (wait) --- other thread unlocks if done or error */
	//pthread_mutex_t callsetup_m;
	pthread_mutex_t adr_m;
	
	void init();
};

#endif /*header*/
#endif /*USE_CAPI20*/

==> sems_2004_01_04.tar.gz: sems_2004_01_04/plug-in/isdngw/IsdnCapiConnection.h <==
#ifdef USE_CAPI20

#ifndef _ISDNCAPICONNECTION_H_
#define _ISDNCAPICONNECTION_H_

#include "AmApi.h"
#include <capi20.h>
#include "IsdnCapiUtil.h"

/* represents a CAPI 2.0 audio connection */

#define CC_STATE_IDLE 1
#define CC_STATE_CONNECTING 2
#define CC_STATE_CONNECTED 3
#define CC_STATE_AUDIO 4
#define CC_STATE_WASTE 5
#define CC_STATE_DISCONNECTED 6

#define NUM_BUF_LEN 100
#define AUDIO_BUFFER_LEN (MSG_SIZE*8)
#define AUDIO_CHUNK_SIZE 180

#define REASON_LEN 1000

class IsdnCapiConnection {
	
	public:
	
	IsdnCapiConnection(); /* constructor */
	IsdnCapiConnection(int controller);
	~IsdnCapiConnection();

	int call(char* caller_number, char* callee_number, int shownumber); /* place a call */
	int accept(); /* accept a call */
	int hangup(); /* hangup a call */

	void onBeforeCallAccept(AmRequest* req);

	/* callback functions: */
	int cb_connect_conf(_cmsg *msg);
	int cb_connect_active_ind(_cmsg* msg);
	int cb_connect_b3_active_ind(_cmsg* msg);
	int cb_connect_b3_conf(_cmsg* msg);
	int cb_connect_ind(_cmsg* msg);
	int cb_data_b3_ind(_cmsg* msg);
	int cb_data_b3_conf(_cmsg* msg);
	int cb_disconnect_ind(_cmsg* msg);
	int cb_disconnect_conf(_cmsg* msg);
	int cb_disconnect_b3_ind(_cmsg* msg);

	/* these are used for actual voice transfer, format is aLaw */
	int getVoiceStream(unsigned char *buf, int size);  /* get audio bytes */
	int putVoiceStream(unsigned char *buf, int size);  /* put audio bytes */

	private:
	
	int id;
	int state;
	unsigned int adr;
	int m_controller;

	int m_code;
	char m_reason[REASON_LEN];

	/* audio data FromIsdn */
	unsigned char fi_audiobuffer[AUDIO_BUFFER_LEN+1];
	unsigned char* fi_readpos;
	unsigned int fi_datalen;
	pthread_mutex_t fi_m;

	/* audio data ToIsdn */
	unsigned char ti_audiobuffer[AUDIO_BUFFER_LEN+1];
	unsigned char* ti_readpos;
	unsigned int ti_datalen;
	pthread_mutex_t ti_m;

	int readFromBuffer(unsigned char* audiobuffer, unsigned char** readpos, unsigned int *datalen, unsigned char* targetbuffer, int bytes);
	int  writeToBuffer(unsigned char* audiobuffer, unsigned char*  readpos, unsigned int *datalen, unsigned char* data, unsigned int bytes);
	
	/* connection setup lock: lock, trigger the call, lock (wait) --- other thread unlocks if done or error */
	pthread_mutex_t callsetup_m;
	
	void init();
};

#endif /*header*/
#endif /*USE_CAPI20*/
